searchData={"items":[{"type":"module","doc":"This GenServer module allows you to run [Litestream](https://litestream.io/) via a port in the background\nso that you can easily backup your SQLite database to an object store.","title":"Litestream","ref":"Litestream.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Litestream.child_spec/1","ref":"Litestream.html#child_spec/1"},{"type":"function","doc":"The `start_link/1` function is used to start the `Litestream` GenServer. After starting the GenServer, the process\nwill download the Litestream binary and start it up to begin database replication. The `Litestream` GenServer\nexpects a Keyword list with the following options:\n\n* `:repo` - The Ecto Repo that manages the SQLite database. REQUIRED\n* `:replica_url` - The URL to which the SQLite database should be backed up. REQUIRED\n* `:access_key_id` - The access key ID to the provided `:replica_url`. REQUIRED\n* `:secret_access_key` - The secret access key to the provided `:replica_url`. REQUIRED\n* `:name` - The name of the GenServer process. By default it is `Litestream`. OPTIONAL\n* `:bin_path` - If you already have access to the Litestream binary, provide the path via this\n                option so that you can skip the download step. OPTIONAL","title":"Litestream.start_link/1","ref":"Litestream.html#start_link/1"},{"type":"function","doc":"This function will start the Litestream process, if it is not currently running. If it is\nalready running, then this operation is effectively a no-op.","title":"Litestream.start_litestream/1","ref":"Litestream.html#start_litestream/1"},{"type":"function","doc":"This function will return the status of the Litestream port with either a `:down` or\n`:running` atom.","title":"Litestream.status/1","ref":"Litestream.html#status/1"},{"type":"function","doc":"This function will cleanly stop the Litestream process, but the GenServer will still be\nrunning.","title":"Litestream.stop_litestream/1","ref":"Litestream.html#stop_litestream/1"},{"type":"module","doc":"This module is used to download the built Litestream binaries.","title":"Litestream.Downloader","ref":"Litestream.Downloader.html"},{"type":"extras","doc":"Easily backup your SQLite database right from Elixir using  Litestream \n \n\n \n   \n     \n   \n\n   \n     \n   \n\n   \n     \n   \n \n\n \n\n# Contents\n\n- [Installation](#installation)\n- [Supporting Litestream](#supporting-litestream)\n- [Setting Up Litestream](#setting-up-litestream)\n- [Attribution](#attribution)","title":"README","ref":"readme.html"},{"type":"extras","doc":"[Available in Hex](https://hex.pm/packages/Litestream), the package can be installed by adding `litestream` to your list of\ndependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:litestream, \"~> 0.4.0\"}\n  ]\nend\n```\n\nDocumentation can be found at [https://hexdocs.pm/litestream](https://hexdocs.pm/litestream).","title":"Installation - README","ref":"readme.html#installation"},{"type":"extras","doc":"If you rely on this library to backup your SQLite databases, it would much appreciated if you can give back to the\nproject in order to help ensure its continued development.\n\nCheckout my [GitHub Sponsorship page](https://github.com/sponsors/akoutmos) if you want to help out!","title":"Supporting Litestream - README","ref":"readme.html#supporting-litestream"},{"type":"extras","doc":"","title":"Gold Sponsors - README","ref":"readme.html#gold-sponsors"},{"type":"extras","doc":"","title":"Silver Sponsors - README","ref":"readme.html#silver-sponsors"},{"type":"extras","doc":"","title":"Bronze Sponsors - README","ref":"readme.html#bronze-sponsors"},{"type":"extras","doc":"After adding `{:litestream, \"~> 0.2.0\"}` in your `mix.exs` file and running `mix deps.get`, open your `application.ex`\nfile and add the following to your supervision tree:\n\n```elixir\n@impl true\ndef start(_type, _args) do\n  children = [\n    # Start the Ecto repository\n    LitescaleTest.Repo,\n    {Litestream, litestream_config()},\n    ...\n  ]\n\n  opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n  Supervisor.start_link(children, opts)\nend\n\ndefp litestream_config do\n  Application.get_env(:my_app, Litestream)\nend\n```\n\nIn your `runtime.exs` (or `dev.exs` if you are just developing locally):\n\n```elixir\nconfig :my_app, Litestream,\n  repo: MyApp.Repo,\n  replica_url: System.fetch_env!(\"REPLICA_URL\"),\n  access_key_id: System.fetch_env!(\"ACCESS_KEY_ID\"),\n  secret_access_key: System.fetch_env!(\"SECRET_ACCESS_KEY\")\n```\n\nWith those in place, you should be all set to go! As soon as your application starts, your database will be\nautomatically synced with your remote destination.","title":"Setting Up Litestream - README","ref":"readme.html#setting-up-litestream"},{"type":"extras","doc":"- The logo for the project is an edited version of an SVG image from the [unDraw project](https://undraw.co/)\n- The Litestream library that this library wraps [Litestream](https://litestream.io)","title":"Attribution - README","ref":"readme.html#attribution"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}